@@ -19,9 +19,9 @@
 
 """The main module for the Orca screen reader."""
 
-__id__        = "$Id: orca.py 3227 2007-11-08 21:28:31Z eitani $"
-__version__   = "$Revision: 3227 $"
-__date__      = "$Date: 2007-11-08 16:28:31 -0500 (Thu, 08 Nov 2007) $"
+__id__        = "$Id: orca.py 3375 2007-12-14 16:48:23Z joanied $"
+__version__   = "$Revision: 3375 $"
+__date__      = "$Date: 2007-12-14 11:48:23 -0500 (Fri, 14 Dec 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -168,6 +168,10 @@ def setLocusOfFocus(event, obj, notifyPresentationManager=True):
         # Either it's None or it's an invalid remote object.
         oldLocusOfFocus = None
 
+    orca_state.focusHistory = \
+        orca_state.focusHistory[:settings.focusHistoryLength - 1]
+    orca_state.focusHistory.insert(0, oldLocusOfFocus)
+
     orca_state.locusOfFocus = obj
     try:
         app = orca_state.locusOfFocus.getApplication()
@@ -417,8 +421,6 @@ def _isNavigationKey(event_string):
     Returns True if this is a navigation key.
     """
 
-    global _orcaModifierPressed
-
     navigationKeys = [ "Left", "Right", "Up", "Down" ]
 
     reply = (event_string in navigationKeys) or _orcaModifierPressed
@@ -430,30 +432,33 @@ def _isNavigationKey(event_string):
 class KeyEventType:
     """Definition of available key event types."""
 
-    """An alphanumeric or punctuation key event."""
+    # An alphanumeric or punctuation key event.
     PRINTABLE = 'PRINTABLE'
 
-    """A modifier key event."""
+    # A modifier key event.
     MODIFIER = 'MODIFIER'
 
-    """A locking key event."""
+    # A locking key event.
     LOCKING = 'LOCKING'
 
-    """A locking key lock event."""
+    # A locking key lock event.
     LOCKING_LOCKED = 'LOCKING_LOCKED'
 
-    """A locking key unlock event."""
+    # A locking key unlock event.
     LOCKING_UNLOCKED = 'LOCKING_UNLOCKED'
 
-    """A function key event."""
+    # A function key event.
     FUNCTION = 'FUNCTION'
 
-    """An action key event."""
+    # An action key event.
     ACTION = 'ACTION'
 
-    """A navigation key event."""
+    # A navigation key event.
     NAVIGATION = 'NAVIGATION'
 
+    def __init__(self):
+        pass
+
 def _keyEcho(event):
     """If the keyEcho setting is enabled, check to see what type of key
     event it is and echo it via speech, if the user wants that type of
@@ -761,7 +766,7 @@ def _processBrailleEvent(command):
 #                                                                      #
 ########################################################################
 
-def _toggleSilenceSpeech(script=None, inputEvent=None):
+def toggleSilenceSpeech(script=None, inputEvent=None):
     """Toggle the silencing of speech.
 
     Returns True to indicate the input event has been consumed.
@@ -893,13 +898,13 @@ def loadUserSettings(script=None, inputEvent=None):
     if _currentPresentationManager >= 0:
         _PRESENTATION_MANAGERS[_currentPresentationManager].activate()
 
-    _showMainWindowGUI()
+    showMainWindowGUI()
 
     httpserver.init()
 
     return True
 
-def _showAppPreferencesGUI(script=None, inputEvent=None):
+def showAppPreferencesGUI(script=None, inputEvent=None):
     """Displays the user interace to configure the settings for a
     specific applications within Orca and set up those app-specific
     user preferences using a GUI.
@@ -918,7 +923,7 @@ def _showAppPreferencesGUI(script=None, inputEvent=None):
 
     return True
 
-def _showPreferencesGUI(script=None, inputEvent=None):
+def showPreferencesGUI(script=None, inputEvent=None):
     """Displays the user interace to configure Orca and set up
     user preferences using a GUI.
 
@@ -936,7 +941,7 @@ def _showPreferencesGUI(script=None, inputEvent=None):
 
     return True
 
-def _showMainWindowGUI(script=None, inputEvent=None):
+def showMainWindowGUI(script=None, inputEvent=None):
     """Displays the Orca main window.
 
     Returns True to indicate the input event has been consumed.
@@ -1008,7 +1013,7 @@ def quitOrca(script=None, inputEvent=None):
 
     return True
 
-def _showFindGUI(script=None, inputEvent=None):
+def showFindGUI(script=None, inputEvent=None):
     """Displays the user interace to perform an Orca Find.
 
     Returns True to indicate the input event has been consumed.
@@ -1068,7 +1073,8 @@ def init(registry):
 
     masks = []
     mask = 0
-    while mask <= (1 << pyatspi.MODIFIER_NUMLOCK):
+    # Cover all masks in 8 bits.
+    while mask <= 255:
         masks.append(mask)
         mask += 1
     pyatspi.Registry.registerKeystrokeListener(
@@ -1113,6 +1119,13 @@ def start(registry):
     registry.start()
 
 def abort(exitCode=1):
+
+    # We know what we are doing here, so tell pylint not to flag
+    # the _exit method call as a warning.  The disable-msg is
+    # localized to just this method.
+    #
+    # pylint: disable-msg=W0212
+
     os._exit(exitCode)
 
 def timeout(signum=None, frame=None):
@@ -1161,7 +1174,7 @@ def shutdown(script=None, inputEvent=None):
         speech.shutdown()
     if settings.enableBraille:
         braille.shutdown()
-    if settings.enableMagnifier:
+    if settings.enableMagnifier or settings.enableMagLiveUpdating:
         mag.shutdown()
 
     pyatspi.Registry.stop()
@@ -1437,7 +1450,7 @@ def main():
 
                 else:
                     usage()
-                    os._exit(2)
+                    abort(2)
 
             if opt in ("-d", "--disable"):
                 feature = val.strip()
@@ -1453,7 +1466,7 @@ def main():
                     _commandLineSettings["showMainWindow"] = False
                 else:
                     usage()
-                    os._exit(2)
+                    abort(2)
 
             if opt in ("-s", "--gui-setup", "--setup"):
                 setupRequested = True
@@ -1465,14 +1478,14 @@ def main():
                 bypassSetup = True
             if opt in ("-?", "--help"):
                 usage()
-                os._exit(0)
+                abort(0)
             if opt in ("-v", "--version"):
                 print "Orca %s" % platform.version
-                os._exit(0)
+                abort(0)
     except:
         debug.printException(debug.LEVEL_OFF)
         usage()
-        os._exit(2)
+        abort(2)
 
     # Do not run Orca if accessibility has not been enabled.
     # We do allow, however, one to force Orca to run via the
@@ -1515,10 +1528,10 @@ def main():
     # user has bypassed any setup via the --no-setup switch.
     #
     if setupRequested and (not bypassSetup) and showGUI:
-        _showPreferencesGUI()
+        showPreferencesGUI()
     elif (not _userSettings) and (not bypassSetup):
         if desktopRunning:
-            _showPreferencesGUI()
+            showPreferencesGUI()
         else:
             _showPreferencesConsole()
 
