@@ -19,9 +19,9 @@
 
 """Custom script for Evolution."""
 
-__id__        = "$Id: Evolution.py 3230 2007-11-09 17:02:46Z richb $"
-__version__   = "$Revision: 3230 $"
-__date__      = "$Date: 2007-11-09 12:02:46 -0500 (Fri, 09 Nov 2007) $"
+__id__        = "$Id: Evolution.py 3354 2007-12-08 02:40:44Z eitani $"
+__version__   = "$Revision: 3354 $"
+__date__      = "$Date: 2007-12-07 21:40:44 -0500 (Fri, 07 Dec 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -278,6 +278,15 @@ class Script(default.Script):
         # Evolution defines new custom roles. We need to make them known
         # to Orca for Speech and Braille output.
 
+        # Pylint is confused and flags several errors of the type:
+        #
+        # E1101:282:Script.__init__: Module 'orca.rolenames' has no 
+        # 'ROLE_CALENDAR_VIEW' member
+        #
+        # So for now, we just disable these errors in this method.
+        #
+        # pylint: disable-msg=E1101
+
         rolenames.ROLE_CALENDAR_VIEW = "Calendar View"
         rolenames.rolenames[rolenames.ROLE_CALENDAR_VIEW] = rolenames.Rolename(
             rolenames.ROLE_CALENDAR_VIEW,
@@ -331,7 +340,8 @@ class Script(default.Script):
                 # the user know when new mail has arrived, even if Evolution
                 # doesn't have focus.
                 #
-                _("Toggle whether we present new mail if we are not the active script."))
+                _("Toggle whether we present new mail " \
+                  "if we are not the active script."))
 
     def getKeyBindings(self):
         """Defines the new key binding for this script. Setup the default
@@ -353,6 +363,16 @@ class Script(default.Script):
                 self.inputEventHandlers["toggleReadMailHandler"]))
         return keyBindings
 
+    def getListeners(self):
+        """Sets up the AT-SPI event listeners for this script.
+        """
+        listeners = default.Script.getListeners(self)
+
+        listeners["object:state-changed:showing"]           = \
+            self.onStateChanged
+
+        return listeners
+
     def toggleReadMail(self, inputEvent):
         """ Toggle whether we present new mail if we not not the active script.+
         Arguments:
@@ -434,7 +454,8 @@ class Script(default.Script):
                                 if orca_state.locusOfFocus and \
                                    orca_state.locusOfFocus.getRole() == \
                                        pyatspi.ROLE_PUSH_BUTTON and \
-                                   (not orca_state.locusOfFocus.getState().contains( \
+                                   (not orca_state.locusOfFocus.\
+                                                   getState().contains( \
                                        pyatspi.STATE_SENSITIVE)):
                                     self.updateBraille(orca_state.locusOfFocus)
                                     speech.speakUtterances(
@@ -628,14 +649,14 @@ class Script(default.Script):
                                               startOffset, endOffset),
                    voice]
 
-    def __sayAllProgressCallback(self, context, type):
+    def __sayAllProgressCallback(self, context, callbackType):
         """Provide feedback during the sayAll operation.
         """
 
-        if type == speechserver.SayAllContext.PROGRESS:
+        if callbackType == speechserver.SayAllContext.PROGRESS:
             #print "PROGRESS", context.utterance, context.currentOffset
             pass
-        elif type == speechserver.SayAllContext.INTERRUPTED:
+        elif callbackType == speechserver.SayAllContext.INTERRUPTED:
             #print "INTERRUPTED", context.utterance, context.currentOffset
             offset = context.currentOffset
             for i in range(0, len(context.obj)):
@@ -646,7 +667,7 @@ class Script(default.Script):
                 else:
                     obj.queryText().setCaretOffset(offset)
                     break
-        elif type == speechserver.SayAllContext.COMPLETED:
+        elif callbackType == speechserver.SayAllContext.COMPLETED:
             #print "COMPLETED", context.utterance, context.currentOffset
             obj = context.obj[len(context.obj)-1]
             obj.queryText().setCaretOffset(context.currentOffset)
@@ -695,6 +716,15 @@ class Script(default.Script):
         - newLocusOfFocus: Accessible that is the new locus of focus
         """
 
+        # Pylint is confused and flags several errors of the type:
+        #
+        # E1101:1040:Script.locusOfFocusChanged: Module 'orca.rolenames'
+        # has no 'ROLE_CALENDAR_EVENT' member
+        #
+        # So for now, we just disable these errors in this method.
+        #
+        # pylint: disable-msg=E1101
+
         brailleGen = self.brailleGenerator
         speechGen = self.speechGenerator
 
