@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 3090 2007-10-18 15:51:40Z richb $"
-__version__   = "$Revision: 3090 $"
-__date__      = "$Date: 2007-10-18 11:51:40 -0400 (Thu, 18 Oct 2007) $"
+__id__        = "$Id: settings.py 3387 2007-12-17 16:34:14Z joanied $"
+__version__   = "$Revision: 3387 $"
+__date__      = "$Date: 2007-12-17 11:34:14 -0500 (Mon, 17 Dec 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -99,6 +99,7 @@ userCustomizableSettings = [
     "enableLockingKeys",
     "enableFunctionKeys",
     "enableActionKeys",
+    "enableNavigationKeys",
     "enableBraille",
     "enableBrailleGrouping",
     "brailleVerbosityLevel",
@@ -106,6 +107,7 @@ userCustomizableSettings = [
     "brailleSelectorIndicator",
     "enableBrailleMonitor",
     "enableMagnifier",
+    "enableMagLiveUpdating",
     "enableMagCursor",
     "enableMagCursorExplicitSize",
     "magCursorSize",
@@ -113,14 +115,33 @@ userCustomizableSettings = [
     "enableMagCrossHair",
     "enableMagCrossHairClip",
     "magCrossHairSize",
+    "magCrossHairColor",
+    "magZoomerType",
     "magZoomerLeft",
     "magZoomerRight",
     "magZoomerTop",
     "magZoomerBottom",
     "magZoomFactor",
+    "enableMagZoomerBorder",
+    "magZoomerBorderSize",
+    "magZoomerBorderColor",
     "enableMagZoomerColorInversion",
+    "magBrightnessLevel",
+    "magBrightnessLevelRed",
+    "magBrightnessLevelBlue",
+    "magBrightnessLevelGreen",
+    "magContrastLevel",
+    "magContrastLevelRed",
+    "magContrastLevelGreen",
+    "magContrastLevelBlue",
     "magSmoothingMode",
     "magMouseTrackingMode",
+    "magControlTrackingMode",
+    "magTextTrackingMode",
+    "magEdgeMargin",
+    "magPointerFollowsFocus",
+    "magPointerFollowsZoomer",
+    "magColorFilteringMode",
     "magSourceDisplay",
     "magTargetDisplay",
     "verbalizePunctuationStyle",
@@ -288,13 +309,19 @@ enableBrailleMonitor    = False
 
 # Strings used to indicate checkbox/radio button states in braille:
 #
-brailleCheckBoxIndicators = ["< >", "<x>"]
+brailleCheckBoxIndicators = ["< >", "<x>", "<->"]
 brailleRadioButtonIndicators = ["& y", "&=y"]
 
 # If True, enable magnification.
 #
 enableMagnifier                  = False
 
+# If True, changes made in the Magnifier pane will take place
+# immediately (i.e. without pressing the apply button).  Making
+# them permanent still requires pressing Apply or OK.
+#
+enableMagLiveUpdating            = True
+
 # If True, show the magnification cursor.
 #
 enableMagCursor                  = True
@@ -323,6 +350,20 @@ enableMagCrossHairClip           = False
 #
 magCrossHairSize                 = 16
 
+# Magnification cross-hair color value (hex color spec).
+#
+magCrossHairColor                   = '#000000'
+
+# Magnification Zoomer type.
+#
+MAG_ZOOMER_TYPE_FULL_SCREEN      = 0
+MAG_ZOOMER_TYPE_TOP_HALF         = 1
+MAG_ZOOMER_TYPE_BOTTOM_HALF      = 2
+MAG_ZOOMER_TYPE_LEFT_HALF        = 3
+MAG_ZOOMER_TYPE_RIGHT_HALF       = 4
+MAG_ZOOMER_TYPE_CUSTOM           = 5
+magZoomerType                    = MAG_ZOOMER_TYPE_FULL_SCREEN
+
 # Magnification zoomer region placement.
 #
 magZoomerLeft                    = screenWidth / 2
@@ -334,23 +375,95 @@ magZoomerBottom                  = screenHeight
 #
 magZoomFactor                    = 4.0
 
+# If True, display a border around the magnification zoomer region.
+#
+enableMagZoomerBorder           = False
+
+# The color and size of the border which separates the target
+# display from the source display.
+#
+magZoomerBorderSize              = 1
+magZoomerBorderColor             = '#000000'
+
 # If True, invert the magnification zoomer colors.
 #
 enableMagZoomerColorInversion    = False
 
+# The brightness levels.  The range is from -1 to 1, with 0
+# being "normal"/no change.
+#
+magBrightnessLevel               = 0
+magBrightnessLevelRed            = 0
+magBrightnessLevelGreen          = 0
+magBrightnessLevelBlue           = 0
+
+# The contrast levels.  The range is from -1 to 1, with 0
+# being "normal"/no change.
+#
+magContrastLevel                 = 0
+magContrastLevelRed              = 0
+magContrastLevelGreen            = 0
+magContrastLevelBlue             = 0
+
+# Magnification libcolorblind color filtering mode (see magColorFilteringMode).
+#
+MAG_COLOR_FILTERING_MODE_NONE                 = 0
+MAG_COLOR_FILTERING_MODE_SATURATE_RED         = 1
+MAG_COLOR_FILTERING_MODE_SATURATE_GREEN       = 2
+MAG_COLOR_FILTERING_MODE_SATURATE_BLUE        = 3
+MAG_COLOR_FILTERING_MODE_DESATURATE_RED       = 4
+MAG_COLOR_FILTERING_MODE_DESATURATE_GREEN     = 5
+MAG_COLOR_FILTERING_MODE_DESATURATE_BLUE      = 6
+MAG_COLOR_FILTERING_MODE_POSITIVE_HUE_SHIFT   = 7
+MAG_COLOR_FILTERING_MODE_NEGATIVE_HUE_SHIFT   = 8
+magColorFilteringMode = MAG_COLOR_FILTERING_MODE_NONE
+
 # Magnification smoothing mode (see magSmoothingMode).
 #
 MAG_SMOOTHING_MODE_BILINEAR      = 0
 MAG_SMOOTHING_MODE_NONE          = 1
 magSmoothingMode                 = MAG_SMOOTHING_MODE_BILINEAR
 
-# Magnification mouse tracking mode (see magMouseTrackingMode).
+# Magnification tracking mode styles (see magMouseTrackingMode,
+# magControlTrackingMode and magTextTrackingMode).
 #
-MAG_MOUSE_TRACKING_MODE_CENTERED     = 0
-MAG_MOUSE_TRACKING_MODE_NONE         = 1
-MAG_MOUSE_TRACKING_MODE_PROPORTIONAL = 2
-MAG_MOUSE_TRACKING_MODE_PUSH         = 3
-magMouseTrackingMode                 = MAG_MOUSE_TRACKING_MODE_CENTERED
+MAG_TRACKING_MODE_CENTERED     = 0
+MAG_TRACKING_MODE_PROPORTIONAL = 1
+MAG_TRACKING_MODE_PUSH         = 2
+MAG_TRACKING_MODE_NONE         = 3
+
+# To retain backward compatibility with previous versions of Orca.
+#
+MAG_MOUSE_TRACKING_MODE_CENTERED = MAG_TRACKING_MODE_CENTERED
+MAG_MOUSE_TRACKING_MODE_PROPORTIONAL = MAG_TRACKING_MODE_PROPORTIONAL
+MAG_MOUSE_TRACKING_MODE_PUSH = MAG_TRACKING_MODE_PUSH
+MAG_MOUSE_TRACKING_MODE_NONE = MAG_TRACKING_MODE_NONE
+
+# Magnification mouse tracking mode.
+#
+magMouseTrackingMode           = MAG_TRACKING_MODE_CENTERED
+
+# Magnification control and menu item tracking mode.
+#
+magControlTrackingMode         = MAG_TRACKING_MODE_PUSH
+
+# Magnification text cursor tracking mode.
+#
+magTextTrackingMode            = MAG_TRACKING_MODE_PUSH
+
+# Magnification edge margin (percentage of screen).
+#
+magEdgeMargin                  = 0
+
+# If enabled, automatically repositions the mouse pointer to the
+# menu item or control with focus.
+#
+magPointerFollowsFocus         = False
+
+# If enabled, automatically repositions the mouse pointer into the
+# zoomer if it's not visible when initially moved.
+#
+magPointerFollowsZoomer        = True
 
 # Magnification source display
 #
@@ -392,6 +505,10 @@ enableFunctionKeys      = True
 #
 enableActionKeys        = True
 
+# If True and key echo is enabled, echo Navigation keys.
+#
+enableNavigationKeys    = False
+
 # If True, show the main Orca window.
 #
 showMainWindow          = True
@@ -431,7 +548,16 @@ progressBarUpdateInterval = 10
 
 # The complete list of possible text attributes.
 #
-allTextAttributes = "bg-color:; bg-full-height:; bg-stipple:; direction:; editable:; family-name:; fg-color:; fg-stipple:; font-effect:none; indent:0; invisible:; justification:left; language:; left-margin:; line-height:100%; paragraph-style:Default; pixels-above-lines:; pixels-below-lines:; pixels-inside-wrap:; right-margin:; rise:; scale:; size:; stretch:; strikethrough:false; style:normal; text-decoration:none; text-rotation:0; text-shadow:none; underline:none; variant:; vertical-align:baseline; weight:400; wrap-mode:; writing-mode:lr-tb;"
+allTextAttributes = \
+    "bg-color:; bg-full-height:; bg-stipple:; direction:; editable:; " \
+    "family-name:; fg-color:; fg-stipple:; font-effect:none; indent:0; " \
+    "invisible:; justification:left; language:; left-margin:; " \
+    "line-height:100%; paragraph-style:Default; pixels-above-lines:; " \
+    "pixels-below-lines:; pixels-inside-wrap:; right-margin:; rise:; " \
+    "scale:; size:; stretch:; strikethrough:false; style:normal; " \
+    "text-decoration:none; text-rotation:0; text-shadow:none; " \
+    "underline:none; variant:; vertical-align:baseline; weight:400; " \
+    "wrap-mode:; writing-mode:lr-tb;"
 
 # The default set of text attributes to speak to the user. Specific
 # application scripts (or individual users can override these values if
@@ -441,7 +567,9 @@ allTextAttributes = "bg-color:; bg-full-height:; bg-stipple:; direction:; editab
 # it won't be spoken. If no value part is given, then that attribute will
 # always be spoken.
 
-enabledSpokenTextAttributes = "size:; family-name:; weight:400; indent:0; underline:none; strikethrough:false; justification:left; style:normal;"
+enabledSpokenTextAttributes = \
+    "size:; family-name:; weight:400; indent:0; underline:none; " \
+    "strikethrough:false; justification:left; style:normal;"
 
 # The default set of text attributes to be brailled for the user. Specific
 # application scripts (or individual users can override these values if
@@ -451,7 +579,9 @@ enabledSpokenTextAttributes = "size:; family-name:; weight:400; indent:0; underl
 # it won't be spoken. If no value part is given, then that attribute will
 # always be brailled.
 
-enabledBrailledTextAttributes = "size:; family-name:; weight:400; indent:0; underline:none; strikethrough:false; justification:left; style:normal;"
+enabledBrailledTextAttributes = \
+    "size:; family-name:; weight:400; indent:0; underline:none; " \
+    "strikethrough:false; justification:left; style:normal;"
 
 # Text Attributes Braille Indicator (see textAttributesBrailleIndicator).
 # The values represent the character to be used in the attrOr
@@ -749,4 +879,19 @@ setScriptMapping(re.compile(_('pidgin')), "gaim")
 
 # Show deprecated messeges in debug output.
 # Set this to True to help find potential pyatspi porting problems
+#
 deprecatedMessages = False
+
+# Focus history length. We keep a reference to past focused accessibles to 
+# maximize on caching.
+#
+focusHistoryLength = 5
+
+# Listen to all AT-SPI events, regardless to if we are using them or not.
+# This is useful for development and debugging.
+#
+listenAllEvents = False
+
+# This is a list of events that Orca should immidiately drop and never look at.
+#
+ignoredEventsList = ['object:bounds-changed']
